<h1 align="center">
    Opt3001
</h1>

<h4 align="center">
    Python support library for the light sensor OPT3001 from Texas Instruments
</h4>

## Description

## Contents

- [Description](#description)
- [Contents](#contents)
- [Install](#install)
- [Usage](#usage)
- [Development](#development)
- [Team](#team)
- [License](#license)

## Install

sudo apt-get install -y python-smbus
pip install opt3001

## Usage

## Development

### Build
python setup.py sdist bdist_wheel

### Upload
twine upload dist/*

## Team

- Thomas Pöhlmann [(@perryrh0dan)](https://github.com/perryrh0dan)

## Licence

[MIT](https://github.com/perryrh0dan/charon/blob/master/license.md)

This repository was generated by [charon](https://github.com/perryrh0dan/charon)
